@@ -79,7 +79,8 @@ class LitModuleBuilder:
             map_location=lambda storage, loc: storage,
         )
         epoch = ckpt["epoch"]
-        lmodule = model_class._load_model_state(ckpt, **kwargs)
+        # use strict=False by default
+        lmodule = model_class._load_model_state(ckpt, strict=False, **kwargs)
         #
         return lmodule, epoch, ckpt
 
@@ -179,7 +180,9 @@ class BaseRunner:
 
         metrics_dict = {**train_val_metrics_dict, **reval_test_metrics_dict}
 
-        trial_metrics = TrialMetrics(lprogress_bar_callback.get_metrics_df())
+        trial_metrics = TrialMetrics.from_metrics_df_list(
+            lprogress_bar_callback.get_metrics_df_list()
+        )
 
         self.__check_trial_metrics(trial_metrics, metrics_dict)
 
@@ -282,9 +285,11 @@ class BaseRunner:
             lmodule_best, trainer, tune_config, loaders_dict, lprogress_bar_callback
         )
 
-        metrics_df = lprogress_bar_callback.get_metrics_df()
-        metrics_df.epoch = best_epoch
-        trial_metrics = TrialMetrics(metrics_df)
+        metrics_df_list = lprogress_bar_callback.get_metrics_df_list()
+        for metrics_df in metrics_df_list:
+            metrics_df.epoch = best_epoch
+
+        trial_metrics = TrialMetrics.from_metrics_df_list(metrics_df_list)
 
         self.__check_trial_metrics(trial_metrics, metrics_dict)
 
@@ -444,17 +449,13 @@ class BaseRunner:
             TRAINER_KWARG_DICT["weights_summary"] = None
         else:
             PTL_CHECKPOINT_PERIOD = 1
-            PTL_CHECKPOINT_SAVE_TOP_K = 3
+            PTL_CHECKPOINT_SAVE_TOP_K = 2
             #
-            metric2optimize = extra_config["metric_to_optimize"]
             checkpoint_callback = ModelCheckpoint(
                 monitor=extra_config["metric_to_optimize"],
                 mode=extra_config["metric_opt_mode"],
                 save_top_k=PTL_CHECKPOINT_SAVE_TOP_K,
                 period=PTL_CHECKPOINT_PERIOD,
-                filename="sample-mnist-{epoch:02d}-{val_loss:.6f}-{metric2optimize:.6f}".replace(
-                    "{metric2optimize", "{" + f"{metric2optimize}"
-                ),
             )
             pl_callbacks.append(checkpoint_callback)
 
@@ -541,6 +542,7 @@ class BaseRunner:
         train_loader_name = extra_config["train_loader_name"]
         train_loader = loaders_dict[train_loader_name]
         #
+        config["n_steps_per_epoch"] = len(train_loader)
         config["n_train_steps"] = len(train_loader) * config["max_epochs"]
         #
         if checkpoint_dir:
